<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ug">
<context>
    <name>PasswordWidget</name>
    <message>
        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="45"/>
        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="128"/>
        <source>Passwords do not match</source>
        <translation>پارول بىردەك ئەمەس</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="54"/>
        <source>The hint is visible to all users. Do not include the password here.</source>
        <translation>پارول ئەسكەرتمىسى ھەممە ئادەمگە كۆرۈنىدۇ ، مەخپىي نومۇر قاتارلىق مۇھىم ئۇچۇرلار بولمىسۇن</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="72"/>
        <source>New Password</source>
        <translation>يېڭى پارول</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="94"/>
        <source>Repeat Password</source>
        <translation>پارولنى يەنە كىرگۈزۈڭ </translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="102"/>
        <source>Password Hint</source>
        <translation>پارول ئەسكەرتمىسى </translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="111"/>
        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="112"/>
        <source>Required</source>
        <translation>چوقۇم تولدۇرۇڭ</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="113"/>
        <source>Optional</source>
        <translation>ئىختىيارىي</translation>
    </message>
</context>
<context>
    <name>PwqualityManager</name>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="61"/>
        <source>Password cannot be empty</source>
        <translation>پارول قۇرۇق قالسا بولمايدۇ</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="62"/>
        <source>Password must have at least %1 characters</source>
        <translation>پارول %1 ھەرپتىن كەم بولماسلىقى كېرەك</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="63"/>
        <source>Password must be no more than %1 characters</source>
        <translation>پارول %1 ھەرپتىن ئېشىپ كەتمەسلىكى كېرەك</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="64"/>
        <source>Password can only contain English letters (case-sensitive), numbers or special symbols (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</source>
        <translation>پارولدا پەقەت ئىنگلىزچە ھەرپلەر (چوڭ-كىچىك) ، سان ياكى ئالاھىدە بەلگىلەر بار (~! @ # $% ^ &amp; * () [] {} \ | /?,. &lt;&gt;)</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="65"/>
        <source>No more than %1 palindrome characters please</source>
        <translation>جاۋاب خەتنىڭ ئۇزۇنلۇقى %1 ھەرپتىن ئېشىپ كەتمىسۇن</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="66"/>
        <source>No more than %1 monotonic characters please</source>
        <translation>مونوتونلۇق بەلگە %1 تىن ئېشىپ كەتمىسۇن</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="67"/>
        <source>No more than %1 repeating characters please</source>
        <translation>قايتىلانغان ھەرپ %1 تىن ئېشىپ كەتمىسۇن</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="68"/>
        <source>The password should differ from the username</source>
        <translation>پارول ئىشلەتكۈچى نامى بىلەن ئوخشاش بولسا بولمايدۇ</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="74"/>
        <source>Password must contain uppercase letters, lowercase letters, numbers and symbols (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</source>
        <translation>پارول چوڭ ھەرپ،كىچىك ھەرپ، سانلار ۋە بەلگىلەردىن ئىبارەت ئۈچ تۈرنى ئۆز ئىچىگە ئېلىشى كېرەك(~!@#$%^&amp;*()[]{}\|/?,.&lt;&gt;)</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="75"/>
        <source>Password must not contain more than 4 palindrome characters</source>
        <translation>پارولدا ئۇدا 4 تىن ئارتۇق قايتىلانما ھەرپ-بەلگە بولسا بولمايدۇ</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="76"/>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="79"/>
        <source>Do not use common words and combinations as password</source>
        <translation>پارولدا دائىم ئۇچرايدىغان ئاددىي سۆز ۋە سۆز بىرىكمىلىرى بولسا بولمايدۇ</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="77"/>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="78"/>
        <source>Create a strong password please</source>
        <translation>پارول بەك ئاددىي، مۇرەككەپرەك بېكىتىڭ</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="85"/>
        <source>It does not meet password rules</source>
        <translation>پارول بىخەتەرلىك تەلىپىگە ئۇيغۇن كەلمەيدۇ</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/reset-password-dialog/utils.h" line="71"/>
        <source>It cannot be empty</source>
        <translation> قۇرۇق قويۇشقا بولمايدۇ</translation>
    </message>
</context>
<context>
    <name>ResetPasswordDialog</name>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="102"/>
        <source>Resetting the password will clear the data stored in the keyring</source>
        <translation>پارولنى قايتا بېكىتسىڭىز مەخپىي ئاچقۇچ ھالقىسىدا ساقلانغان سانلىق مەلۇماتلار تازىلىنىدۇ</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="104"/>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="160"/>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="207"/>
        <source>Cancel</source>
        <translation>بىكار قىلىش</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="113"/>
        <source>Security Questions</source>
        <translation>بىخەتەرلىك سوئاللىرى</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="148"/>
        <source>Reset Password</source>
        <translation>پارولنى قايتا بېكىتىش</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="149"/>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="192"/>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="195"/>
        <source>Next</source>
        <translation>كېيىنكى </translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="152"/>
        <source>Reset Password By UOS ID</source>
        <translation>Union ID نىڭ پارولىنى قايتا بېكىتىش</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="153"/>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="192"/>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="195"/>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="203"/>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="210"/>
        <source>Reset</source>
        <translation>قايتا بېكىتىش</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="159"/>
        <source>Resetting the password will clear the data stored in your keyring, and you should log in again, please save files in advance</source>
        <translation>پارولنى قايتا بېكىستسىڭىز مەخپىي ئاچقۇچ ھالقىسىدا ساقلانغان سانلىق مەلۇماتلار تازىلىنىدۇ، ھەمدە بۇ ئىشلەتكۈچى قايتىدىن كىرىدۇ، ھۆججەتلىرىڭىزنى ئالدىن ساقلاشقا دىققەت قىلىڭ</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="160"/>
        <source>Confirm and Reset</source>
        <translation>قايتا بېكىتشىنى جەزملەش</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="285"/>
        <source>Successfully reset, please log in and unlock with the new password</source>
        <translation>پارول قايتا بېكىتىلدى، يېڭى پارولدا كىرىڭ</translation>
    </message>
</context>
<context>
    <name>SecurityLevelItem</name>
    <message>
        <location filename="../src/frame/widgets/securitylevelitem.cpp" line="57"/>
        <source>Weak</source>
        <translation>ئاجىز</translation>
    </message>
    <message>
        <location filename="../src/frame/widgets/securitylevelitem.cpp" line="67"/>
        <source>Medium</source>
        <translation>ئوتتۇرىدا</translation>
    </message>
    <message>
        <location filename="../src/frame/widgets/securitylevelitem.cpp" line="77"/>
        <source>Strong</source>
        <translation>كۈچلۈك</translation>
    </message>
</context>
<context>
    <name>SecurityQuestionsWidget</name>
    <message>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="109"/>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="110"/>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="111"/>
        <source>Required</source>
        <translation>چوقۇم تولدۇرۇڭ</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="113"/>
        <source>What&apos;s the name of the city where you were born?</source>
        <translation>سىز تۇغۇلغان شەھەرنىڭ نامى نېمە؟</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="114"/>
        <source>What&apos;s the name of the first school you attended?</source>
        <translation>مەكتىپىڭىزنىڭ نامى نېمە؟</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="115"/>
        <source>Who do you love the most in this world?</source>
        <translation>سىز كىمنى ئەڭ ياخشى كۆرىسىز؟</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="116"/>
        <source>What&apos;s your favorite animal?</source>
        <translation>سىز ئەڭ ياخشى كۆرىدىغان ھايۋان قايسى؟</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="117"/>
        <source>What&apos;s your favorite song?</source>
        <translation>سىز ئەڭ ياخشى كۆرىدىغان مۇزىكا قايسى؟</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="118"/>
        <source>What&apos;s your nickname?</source>
        <translation>تەخەللۇسىڭىز نېمە؟</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="168"/>
        <source>Wrong answer</source>
        <translation>جاۋاب خاتا</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="183"/>
        <source>Keep the answer under 30 characters</source>
        <translation>جاۋابىڭىز 30 ھەرپتىن ئاز بولسۇن</translation>
    </message>
</context>
<context>
    <name>UnionIDWidget</name>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="45"/>
        <source>Phone/Email</source>
        <translation>تېلېفون/ئېلخەت</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="51"/>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="118"/>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="267"/>
        <source>Get Code</source>
        <translation>دەلىللەش كودىغا ئېرىشىش</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="71"/>
        <source>Connecting to the Internet...</source>
        <translation>تور ئۇلىنىۋاتىدۇ...</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="83"/>
        <source>The user account is not linked to UOS ID</source>
        <translation>نۆۋەتتىكى  ھېسابات  نومۇرى UOS IDغا ئۇلانمىغان</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="96"/>
        <source>Network disconnected, please retry after connected</source>
        <translation>تور ئۇلىنىشى ئۈزۈلدى، ئۇلىغاندىن كىيىن قايتا سىناپ بېقىڭ</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="116"/>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="117"/>
        <source>Required</source>
        <translation>چوقۇم تولدۇرۇڭ</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="158"/>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="175"/>
        <source>Phone/Email format is incorrect</source>
        <translation>تېلېفون/ئېلخەت فورماتى خاتا</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="229"/>
        <source>System error</source>
        <translation>سىستېما خاتالىقى </translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="231"/>
        <source>Login expired, please sign in to the UOS ID again</source>
        <translation>كىرىش ۋاقتى ئۆتۈپ كەتكەن، UOS ID غا قايتا كىرىڭ</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="233"/>
        <source>Network error</source>
        <translation>تور خاتالىقى </translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="235"/>
        <source>You have reached the number limit to get the code today</source>
        <translation>بۈگۈنكى دەلىللەش كودىغا ئېرىشىش سانىڭىز توشتى</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="236"/>
        <source>The UOS ID is not linked to a user account</source>
        <translation>بۇ UOS ID غا يەرلىك ھېسابات نومۇرى باغلانمىغان</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="270"/>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="312"/>
        <source>Resend (%1s)</source>
        <translation> قايىتىدىن ئېرىشش (%1s)</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="332"/>
        <source>Failed to get the code</source>
        <translation>كودقا ئېرىشەلمىدى</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="357"/>
        <source>Wrong verification code</source>
        <translation>دەلىللەش كودى خاتا</translation>
    </message>
</context>
</TS>